==> Banners-2.3.7.tar.gz: Banners/action.save_admin_prefs.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: Banners (c) 2008 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow management, display,
#  and tracking of banner images.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if (!$this->CheckPermission ('Modify Site Preferences')) exit;

if (isset ($params['cancel']))
  {
    $this->RedirectToTab($id);
  }

    $this->SetPreference ('subnet_exclusions',
			  isset ($params['subnet_exclusions']) ?
			  $params['subnet_exclusions'] : '0');

if( isset($params['reset_template']) )
  {
    $fn = dirname(__FILE__).'/templates/orig_category_template.tpl';
    $data = @file_get_contents($fn);
    $this->SetPreference('default_template',$data);
  }
else
  {
    $this->SetPreference('default_template',$params['default_template']);
  }
$this->RedirectToTab($id);
?>

==> Banners-2.6.tar.gz: Banners/action.save_admin_prefs.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: Banners (c) 2008 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow management, display,
#  and tracking of banner images.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if (!$this->CheckPermission ('Modify Site Preferences')) exit;

$this->SetCurrentTab('preferences');

if (isset ($params['cancel']))
  {
    $this->RedirectToTab($id);
  }

$this->SetPreference ('subnet_exclusions',
		      isset ($params['subnet_exclusions']) ?
		      $params['subnet_exclusions'] : '0');
$this->SetPreference ('hide_from_bots',(int)$params['hide_from_bots']);
$this->SetPreference('statreport_linesperpage',(int)$params['statreport_linesperpage']);

if( isset($params['reset_template']) )
  {
    $fn = dirname(__FILE__).'/templates/orig_category_template.tpl';
    $data = @file_get_contents($fn);
    $this->SetPreference('default_template',$data);
  }
else
  {
    $this->SetPreference('default_template',$params['default_template']);
  }
$this->RedirectToTab($id);
?>
